@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0600';
+our $VERSION = '0.0601';
 
 use Moo;
 use strictures 2;
@@ -96,8 +96,7 @@ sub _build_groups {
     return [ (0) x @{ $self->pool } ];
 }
 
-
-has pool_group => (
+has _pool_group => (
     is       => 'ro',
     init_arg => undef,
 );
@@ -116,7 +115,7 @@ sub BUILD {
     for my $i (0 .. @{ $self->pool } - 1) {
         $pool_group{ $self->pool->[$i] } = $self->groups->[$i];
     }
-    $self->{pool_group} = \%pool_group;
+    $self->{_pool_group} = \%pool_group;
 }
 
 
@@ -132,7 +131,7 @@ sub motif {
     my $group_name = '';
 
     while ( $sum < $self->size ) {
-        my $name = $self->pool_select->();
+        my $name = $self->pool_select->(); # Chooses a note duration
 
         # Compute grouping
         if ($group_num) {
@@ -140,8 +139,8 @@ sub motif {
             $name = $group_name;
         }
         else {
-            if ($self->pool_group->{$name}) {
-                $group_num = $self->pool_group->{$name} - 1;
+            if ($self->_pool_group->{$name}) {
+                $group_num = $self->_pool_group->{$name} - 1;
                 $group_name = $name;
             }
             else {
@@ -150,20 +149,24 @@ sub motif {
             }
         }
 
-        my $size = $self->_duration($name);
-        my $diff = $self->size - $sum;
+        my $size = $self->_duration($name); # Get the duration of the note
+        my $diff = $self->size - $sum; # How much is left?
 
+        # The difference is less than the min_size
         last
             if sprintf( $format, $diff ) < sprintf( $format, $self->_min_size );
 
+        # The note duration is greater than the difference
         next
             if sprintf( $format, $size ) > sprintf( $format, $diff );
 
+        # Increment the sum by the note duration
         $sum += $size;
 
         warn(__PACKAGE__,' ',__LINE__," $name, $size, $sum\n")
             if $self->verbose;
 
+        # Add the note to the motif if the sum is less than the total duration size
         push @$motif, $name
             if $sum <= $self->size;
     }
@@ -200,7 +203,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0600
+version 0.0601
 
 =head1 SYNOPSIS
 
@@ -320,15 +323,6 @@ Default: Zero for each pool entry
 * Zero and one mean the same thing for grouping.  So if needed, an
 entry should have a value greater than one.
 
-=head2 pool_group
-
-  $pool_group = $mdp->pool_group;
-
-A hash reference of pool keys and group values, respectively.
-
-This attribute is computed and any setting given in the constructor is
-ignored.
-
 =head2 verbose
 
   $verbose = $mdp->verbose;
